// /utils/request.ts

import axios from 'axios'
import {useUserStore} from '@/pinia/modules/user'
const userStore = useUserStore()
//创建axios实例
const request = axios.create({
    baseURL: import.meta.env.VITE_BASE_API,
    // timeout: 9999999,
})
//请求拦截
request.interceptors.request.use((config) => {
    const userStore = useUserStore()
    if (userStore.token !== '') {
        config.headers.token = userStore.token
    }
    return config
})

//响应拦截
request.interceptors.response.use(
    (response) => {
        return response.data
    },
    (error) => {
        let message = ''
        const status = error.response.status
        switch (status) {
            case 401:
                message = 'TOKEN过期'
                break
            case 403:
                message = '无权访问'
                break
            case 404:
                message = '请求地址错误'
                break
            case 500:
                message = '服务器出现问题'
                break
            default:
                message = '网络出现问题'
                break
        }
        //提示错误信息
        //...
        return Promise.reject(error)
    },
)
//对外暴露
export default request
